# mypy-boto3-service-quotas

[![PyPI - mypy-boto3-service-quotas](https://img.shields.io/pypi/v/mypy-boto3-service-quotas.svg?color=blue)](https://pypi.org/project/mypy-boto3-service-quotas)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-service-quotas.svg?color=blue)](https://pypi.org/project/mypy-boto3-service-quotas)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.ServiceQuotas 1.17.36](https://boto3.amazonaws.com/v1/documentation/api/1.17.36/reference/services/service-quotas.html#ServiceQuotas) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 4.4.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-service-quotas](#mypy-boto3-service-quotas)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `ServiceQuotas` service.

```bash
python -m pip install boto3-stubs[service-quotas]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[service-quotas]` in your environment: `python -m pip install 'boto3-stubs[service-quotas]'`

Both type checking and auto-complete should work for `ServiceQuotas` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[service-quotas]` in your environment: `python -m pip install 'boto3-stubs[service-quotas]'`

Both type checking and auto-complete should work for `ServiceQuotas` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[service-quotas]` in your environment: `python -m pip install 'boto3-stubs[service-quotas]'`
- Run `mypy` as usual

Type checking should work for `ServiceQuotas` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[service-quotas]` in your environment: `python -m pip install 'boto3-stubs[service-quotas]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `ServiceQuotas` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`ServiceQuotasClient` provides annotations for `boto3.client("service-quotas")`.

```python
import boto3

from mypy_boto3_service_quotas import ServiceQuotasClient

client: ServiceQuotasClient = boto3.client("service-quotas")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: ServiceQuotasClient = session.client("service-quotas")
```

### Paginators annotations

`mypy_boto3_service_quotas.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_service_quotas import ServiceQuotasClient
from mypy_boto3_service_quotas.paginator import (
    ListAWSDefaultServiceQuotasPaginator,
    ListRequestedServiceQuotaChangeHistoryPaginator,
    ListRequestedServiceQuotaChangeHistoryByQuotaPaginator,
    ListServiceQuotaIncreaseRequestsInTemplatePaginator,
    ListServiceQuotasPaginator,
    ListServicesPaginator,
)

client: ServiceQuotasClient = boto3.client("service-quotas")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_aws_default_service_quotas_paginator: ListAWSDefaultServiceQuotasPaginator = client.get_paginator("list_aws_default_service_quotas")
list_requested_service_quota_change_history_paginator: ListRequestedServiceQuotaChangeHistoryPaginator = client.get_paginator("list_requested_service_quota_change_history")
list_requested_service_quota_change_history_by_quota_paginator: ListRequestedServiceQuotaChangeHistoryByQuotaPaginator = client.get_paginator("list_requested_service_quota_change_history_by_quota")
list_service_quota_increase_requests_in_template_paginator: ListServiceQuotaIncreaseRequestsInTemplatePaginator = client.get_paginator("list_service_quota_increase_requests_in_template")
list_service_quotas_paginator: ListServiceQuotasPaginator = client.get_paginator("list_service_quotas")
list_services_paginator: ListServicesPaginator = client.get_paginator("list_services")
```







### Typed dictionations

`mypy_boto3_service_quotas.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_service_quotas.type_defs import (
    ErrorReasonTypeDef,
    MetricInfoTypeDef,
    QuotaPeriodTypeDef,
    RequestedServiceQuotaChangeTypeDef,
    ServiceInfoTypeDef,
    ServiceQuotaIncreaseRequestInTemplateTypeDef,
    ServiceQuotaTypeDef,
    TagTypeDef,
    GetAWSDefaultServiceQuotaResponseTypeDef,
    GetAssociationForServiceQuotaTemplateResponseTypeDef,
    GetRequestedServiceQuotaChangeResponseTypeDef,
    GetServiceQuotaIncreaseRequestFromTemplateResponseTypeDef,
    GetServiceQuotaResponseTypeDef,
    ListAWSDefaultServiceQuotasResponseTypeDef,
    ListRequestedServiceQuotaChangeHistoryByQuotaResponseTypeDef,
    ListRequestedServiceQuotaChangeHistoryResponseTypeDef,
    ListServiceQuotaIncreaseRequestsInTemplateResponseTypeDef,
    ListServiceQuotasResponseTypeDef,
    ListServicesResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    PaginatorConfigTypeDef,
    PutServiceQuotaIncreaseRequestIntoTemplateResponseTypeDef,
    RequestServiceQuotaIncreaseResponseTypeDef,
)

def get_structure() -> ErrorReasonTypeDef:
    return {
      ...
    }
```
